/**
 * Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
 *
 * This software is the property of WSO2 Inc. and its suppliers, if any.
 * Dissemination of any information or reproduction of any material contained
 * herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
 * You may not alter or remove any copyright or other notice from copies of this content."
 */

/**
 * Enum for Branding Preference Types.
 *
 * @readonly
 * @enum {string}
 */
export enum BrandingPreferenceTypes {
    /**
     * Branding Preference for the Organization.
     * @type {string}
     */
    ORG = "ORG"
}

/**
 * Interface Branding preference object.
 */
export interface BrandingPreferenceInterface {
    /**
     * Organization's basic details.
     */
    colors: BrandingPreferenceColorsInterface;
    /**
     * Organization's basic details.
     */
    organizationDetails: BrandingPreferenceOrganizationDetailsInterface;
    /**
     * images such as Logo, Favicon, etc.
     */
    images: BrandingPreferenceImagesInterface;
    /**
     * Links for policies, etc.
     */
    urls: BrandingPreferenceURLInterface;
    /**
     * Stylesheets for login pages etc..
     */
    stylesheets: BrandingPreferenceStylesheetsInterface;
    /**
     * Configurations.
     */
    configs: BrandingPreferenceConfigInterface;
}

/**
 * Interface Branding preference organization details.
 */
export interface BrandingPreferenceColorsInterface {
    /**
     * Hex value of the theme primary color.
     */
    primary: string;
}

/**
 * Interface Branding preference organization details.
 */
export interface BrandingPreferenceOrganizationDetailsInterface {
    /**
     * Site title appearing on the browser tab.
     */
    siteTitle: string;
    /**
     * Copyright for the footer.
     */
    copyrightText: string;
    /**
     * Support email to be shown for Org members.
     */
    supportEmail: string;
}

/**
 * Interface Branding preference images.
 */
export interface BrandingPreferenceImagesInterface {
    /**
     * Organization Logo.
     */
    logo: {
        imgURL: string;
        altText: string;
    };
    /**
     * Organization Favicon.
     */
    favicon: {
        imgURL: string;
    };
}

/**
 * Interface Branding preference URLs.
 */
export interface BrandingPreferenceURLInterface {
    /**
     * Link for Privacy Policy.
     */
    privacyPolicyURL: string;
    /**
     * Link for Terms of Service.
     */
    termsOfUseURL: string;
    /**
     * Link for Cookie Policy.
     */
    cookiePolicyURL: string;
}

/**
 * Interface Branding preference stylesheets.
 */
export interface BrandingPreferenceStylesheetsInterface {
    /**
     * Login portal stylesheet.
     */
    accountApp: string;
}

/**
 * Interface Branding preference configurations.
 */
export interface BrandingPreferenceConfigInterface {
    /**
     * Should the changes be published?
     */
    isBrandingEnabled: boolean;
}

/**
 * Interface for the Branding Preference API response.
 */
export interface BrandingPreferenceAPIResponseInterface {
    /**
     * Preference type.
     */
    type: BrandingPreferenceTypes;
    /**
     * Requested resource name.
     */
    name: string;
    /**
     * Resource locale.
     */
    locale: string;
    /**
     * Preference object.
     */
    preference: BrandingPreferenceInterface;
}
