<!--
~ Copyright (c) 2021, WSO2 Inc. (http://www.wso2.com). All Rights Reserved.
~
~ This software is the property of WSO2 Inc. and its suppliers, if any.
~ Dissemination of any information or reproduction of any material contained
~ herein in any form is strictly forbidden, unless permitted by WSO2 expressly.
~ You may not alter or remove any copyright or other notice from copies of this content."
-->

<%@ page contentType="text/html;charset=UTF-8" language="java" %>

<%@ page import="org.apache.commons.lang.StringUtils" %>
<%@ page import="org.owasp.encoder.Encode" %>
<%@ page import="org.wso2.carbon.identity.mgt.endpoint.util.IdentityManagementEndpointConstants" %>
<%@ page import="org.wso2.carbon.identity.mgt.endpoint.util.IdentityManagementEndpointUtil" %>
<%@ page import="org.wso2.carbon.identity.core.util.IdentityTenantUtil" %>
<%@ page import="java.io.File" %>

<jsp:directive.include file="includes/localize.jsp"/>

<%
    boolean error = IdentityManagementEndpointUtil.getBooleanValue(request.getAttribute("error"));
    String errorMsg = IdentityManagementEndpointUtil.getStringValue(request.getAttribute("errorMsg"));
    String callback = (String) request.getAttribute(IdentityManagementEndpointConstants.CALLBACK);
    String username = request.getParameter("username");
    String userStoreDomain = request.getParameter("userstoredomain");
    String type = request.getParameter("type");
    String spId = request.getParameter("spId");
    String tenantDomain = (String) request.getAttribute(IdentityManagementEndpointConstants.TENANT_DOMAIN);
    if (StringUtils.isBlank(tenantDomain)) {
        tenantDomain = (String) session.getAttribute(IdentityManagementEndpointConstants.TENANT_DOMAIN);
    }
    if (StringUtils.isBlank(username)) {
        username = (String) request.getAttribute("username");
    }
    if (StringUtils.isBlank(userStoreDomain)) {
        userStoreDomain = (String) request.getAttribute("userstoredomain");
    }

%>

<!doctype html>
<html>
    <head>
        <%
            File headerFile = new File(getServletContext().getRealPath("extensions/header.jsp"));
            if (headerFile.exists()) {
        %>
        <jsp:include page="extensions/header.jsp"/>
        <% } else { %>
        <jsp:include page="includes/header.jsp"/>
        <% } %>
    </head>
    <body class="login-portal layout recovery-layout">
        <div class="page-wrapper">
            <main class="center-segment">
                <div class="ui container medium center aligned middle aligned">
                    <!-- product-title -->
                    <%
                        File productTitleFile = new File(getServletContext().getRealPath("extensions/product-title.jsp"));
                        if (productTitleFile.exists()) {
                    %>
                    <jsp:include page="extensions/product-title.jsp"/>
                    <% } else { %>
                    <jsp:include page="includes/product-title.jsp"/>
                    <% } %>
                    <div class="ui segment">
                        <!-- content -->
                        <h2>
                            <% if ("invite".equalsIgnoreCase(type)) { %>
                            <%=IdentityManagementEndpointUtil.i18n(recoveryResourceBundle, "Set.Password")%>
                            <% } else { %>
                            <%=IdentityManagementEndpointUtil.i18n(recoveryResourceBundle, "Reset.Password")%>
                            <% } %>
                        </h2>
    
                        <% if (error) { %>
                        <div class="ui visible negative message" id="server-error-msg">
                            <%=IdentityManagementEndpointUtil.i18nBase64(recoveryResourceBundle, errorMsg)%>
                        </div>
                        <% } %>
                        <div id="ui visible negative message" hidden="hidden"></div>
    
                        <div class="segment-form">
                            <form class="ui large form" method="post" action="completepasswordreset.do" id="passwordResetForm">
                                <%
                                if (StringUtils.isNotBlank(spId)) {
                                %>
                                <input id="spId" name="spId" type="hidden" value="<%=spId%>"/>
                                <%
                                }
                                %>
                                <div class="ui negative message" hidden="hidden" id="error-msg"></div>
                                <div class="field mt-5 mb-3">
                                    <label>
                                        <%=IdentityManagementEndpointUtil.i18n(recoveryResourceBundle,
                                        "Enter.new.password")%>
                                    </label>
                                    <div class="ui right icon input">
                                        <input
                                            id="reset-password"
                                            name="reset-password"
                                            type="password"
                                            required=""
                                        />
                                        <i id="passwordShowHide" class="eye link icon slash"
                                           onclick="passwordShowToggle()"></i>
                                    </div>
                                </div>
                                <div id="password-validation-block">
                                    <div class="password-policy-description mb-2">
                                        <i id="password-validation-neutral-length" class="inverted grey circle icon"></i>
                                        <i id="password-validation-cross-length" style="display: none;" class="red times circle icon"></i>
                                        <i id="password-validation-check-length" style="display: none;" class="green check circle icon"></i>
                                        <p class="pl-4">More than 8 characters</p>
                                    </div>
                                    <div class="password-policy-description mb-2">
                                        <i id="password-validation-neutral-case" class="inverted grey circle icon"></i>
                                        <i id="password-validation-cross-case" style="display: none;" class="red times circle icon"></i>
                                        <i id="password-validation-check-case" style="display: none;" class="green check circle icon"></i>
                                        <p class="pl-4">At least one uppercase and lowercase letter</p>
                                    </div>
                                    <div class="password-policy-description mb-2">
                                        <i id="password-validation-neutral-number" class="inverted grey circle icon"></i>
                                        <i id="password-validation-cross-number" style="display: none;" class="red times circle icon"></i>
                                        <i id="password-validation-check-number" style="display: none;" class="green check circle icon"></i>
                                        <p class="pl-4">At least one number</p>
                                    </div>
                                    <div class="password-policy-description">
                                        <i id="password-validation-neutral-chars" class="inverted grey circle icon"></i>
                                        <i id="password-validation-cross-chars" style="display: none;" class="red times circle icon"></i>
                                        <i id="password-validation-check-chars" style="display: none;" class="green check circle icon"></i>
                                        <p class="pl-4">At least one of the symbols <code>(!@#$%^&*)</code></p>
                                    </div>
                                </div>
    
                                <%
                                    if (StringUtils.isNotBlank(username)) {
                                %>
                                <div>
                                    <input type="hidden" name="username" value="<%=Encode.forHtmlAttribute(username) %>"/>
                                </div>
                                <%
                                    }
                                    if (StringUtils.isNotBlank(callback)) {
                                %>
                                <div>
                                    <input type="hidden" name="callback" value="<%=Encode.forHtmlAttribute(callback) %>"/>
                                </div>
                                <%
                                    }
                                    if (StringUtils.isNotBlank(userStoreDomain)) {
                                %>
                                <div>
                                    <input type="hidden" name="userstoredomain"
                                           value="<%=Encode.forHtmlAttribute(userStoreDomain)%>"/>
                                </div>
                                <%
                                    }
                                    if (!IdentityTenantUtil.isTenantQualifiedUrlsEnabled() &&
                                                StringUtils.isNotBlank(tenantDomain)) {
                                %>
                                <div>
                                    <input type="hidden" name="tenantdomain" value="<%=Encode.forHtmlAttribute(tenantDomain) %>"/>
                                </div>
                                <%
                                    }
                                    if (StringUtils.isNotBlank(type)) {
                                %>
                                <div>
                                    <input type="hidden" name="type" value="<%=Encode.forHtmlAttribute(type) %>"/>
                                </div>
                                <%
                                    }
                                %>
                               <div class="field mt-5 mb-3">
                                    <label>
                                        <%=IdentityManagementEndpointUtil.i18n(recoveryResourceBundle, "Confirm.password")%>
                                    </label>
                                    <div class="ui right icon input">
                                        <input
                                            id="reset-password2"
                                            name="reset-password2"
                                            type="password"
                                            data-match="reset-password"
                                            required=""
                                        />
                                        <i id="confirmPasswordShowHide" class="eye link icon slash"
                                           onclick="confirmPasswordShowToggle()"></i>
                                    </div>
                                </div>
                                <div id="password-validation-block">
                                    <div class="password-policy-description">
                                        <i id="password-validation-neutral-match" class="inverted grey circle icon"></i>
                                        <i id="password-validation-cross-match" style="display: none;" class="red times circle icon"></i>
                                        <i id="password-validation-check-match" style="display: none;" class="green check circle icon"></i>
                                        <p class="pl-4">Both passwords should match</p>
                                    </div>
                                </div>
                                <div class="ui divider hidden"></div>
    
                                <div class="align-right buttons">
                                    <button id="submit"
                                            class="ui primary button"
                                            type="submit"><%=IdentityManagementEndpointUtil.i18n(recoveryResourceBundle,
                                            "Proceed")%>
                                    </button>
                                </div>
                            </form>
                        </div>
                    </div>
                </div>
            </main>
        </div>
        <!-- /content/body -->
        <!-- product-footer -->
        <%
            File productFooterFile = new File(getServletContext().getRealPath("extensions/product-footer.jsp"));
            if (productFooterFile.exists()) {
        %>
        <jsp:include page="extensions/product-footer.jsp"/>
        <% } else { %>
        <jsp:include page="includes/product-footer.jsp"/>
        <% } %>

        <!-- footer -->
        <%
            File footerFile = new File(getServletContext().getRealPath("extensions/footer.jsp"));
            if (footerFile.exists()) {
        %>
        <jsp:include page="extensions/footer.jsp"/>
        <% } else { %>
        <jsp:include page="includes/footer.jsp"/>
        <% } %>

        <script type="text/javascript">
            var passwordField = $("#reset-password");
            var passwordConfirmField = $("#reset-password2");

            $(document).ready(function () {

                passwordField.keyup(function() {
                    validatePassword();
                    validateConfirmPassword();
                });

                passwordConfirmField.keyup(function() {
                    validateConfirmPassword();
                });

                passwordField.focusout(function() {
                    displayPasswordCross();
                });

                passwordConfirmField.focusout(function() {
                    displayConfirmPasswordCross();
                });

                $("#passwordResetForm").submit(function (e) {
                    $("#server-error-msg").remove();

                    return passwordSubmitValidation();
                });
            });

            var password1 = true;
            var password2 = true;

            function passwordShowToggle(){
                if(password1) {
                    password1 = false;
                    document.getElementById("passwordShowHide").classList.remove("slash");
                    document.getElementById("reset-password").setAttribute("type","text");
                } else{
                    password1 = true;
                    document.getElementById("passwordShowHide").classList.add("slash");
                    document.getElementById("reset-password").setAttribute("type","password");
                }
            }

            function confirmPasswordShowToggle(){
                if(password2) {
                    password2 = false;
                    document.getElementById("confirmPasswordShowHide").classList.remove("slash");
                    document.getElementById("reset-password2").setAttribute("type","text");
                } else{
                    password2 = true;
                    document.getElementById("confirmPasswordShowHide").classList.add("slash");
                    document.getElementById("reset-password2").setAttribute("type","password");
                }
            }

            /**
             * Util function to validate password
             */
            function validatePassword() {
                var lowerCaseLetters = /[a-z]/g;
                var upperCaseLetters = /[A-Z]/g;
                var numbers = /[0-9]/g;
                var chars = /[!@#$%^&*~]/g;

                if (passwordField.val().length >= 8) {
                    $("#password-validation-check-length").css('display', 'block');
                    $("#password-validation-neutral-length").css('display', 'none');
                    $("#password-validation-cross-length").css('display', 'none');
                } else {
                    $("#password-validation-neutral-length").css('display', 'block');
                    $("#password-validation-check-length").css('display', 'none');
                    $("#password-validation-cross-length").css('display', 'none');
                }

                if (passwordField.val().match(lowerCaseLetters) && passwordField.val().match(upperCaseLetters)) {
                    $("#password-validation-check-case").css('display', 'block');
                    $("#password-validation-neutral-case").css('display', 'none');
                    $("#password-validation-cross-case").css('display', 'none');
                } else {
                    $("#password-validation-neutral-case").css('display', 'block');
                    $("#password-validation-check-case").css('display', 'none');
                    $("#password-validation-cross-case").css('display', 'none');
                }

                if (passwordField.val().match(numbers)) {
                    $("#password-validation-check-number").css('display', 'block');
                    $("#password-validation-neutral-number").css('display', 'none');
                    $("#password-validation-cross-number").css('display', 'none');
                } else {
                    $("#password-validation-neutral-number").css('display', 'block');
                    $("#password-validation-check-number").css('display', 'none');
                    $("#password-validation-cross-number").css('display', 'none');
                }

                if (passwordField.val().match(chars)) {
                    $("#password-validation-check-chars").css('display', 'block');
                    $("#password-validation-neutral-chars").css('display', 'none');
                    $("#password-validation-cross-chars").css('display', 'none');
                } else {
                    $("#password-validation-neutral-chars").css('display', 'block');
                    $("#password-validation-check-chars").css('display', 'none'); 
                    $("#password-validation-cross-chars").css('display', 'none');
                }
            }

            /**
             * Util function to validate confirm password
             */
            function validateConfirmPassword() {
                if (passwordField.val() !== "" && passwordField.val() === passwordConfirmField.val()) {
                    $("#password-validation-check-match").css('display', 'block');
                    $("#password-validation-neutral-match").css('display', 'none');
                    $("#password-validation-cross-match").css('display', 'none');
                } else {
                    $("#password-validation-neutral-match").css('display', 'block');
                    $("#password-validation-check-match").css('display', 'none');
                    $("#password-validation-cross-match").css('display', 'none');
                }
            }

            /**
             * Function to enable cross marks on unmet criteria when submitting
             */
            function passwordSubmitValidation() {
                var lowerCaseLetters = /[a-z]/g;
                var upperCaseLetters = /[A-Z]/g;
                var numbers = /[0-9]/g;
                var chars = /[!@#$%^&*~]/g;

                var validPassword = true;

                if (passwordField.val().length < 8) {
                    validPassword = false;
                }

                if (!(passwordField.val().match(lowerCaseLetters) && passwordField.val().match(upperCaseLetters))) {
                    validPassword = false;
                }

                if (!passwordField.val().match(numbers)) {
                    validPassword = false;
                }

                if (!passwordField.val().match(chars)) {
                    validPassword = false;
                }

                if (!(passwordField.val() !== "" && passwordField.val() === passwordConfirmField.val())) {
                    validPassword = false;
                }

                return validPassword;
            }

            function displayPasswordCross() {
                var lowerCaseLetters = /[a-z]/g;
                var upperCaseLetters = /[A-Z]/g;
                var numbers = /[0-9]/g;
                var chars = /[!@#$%^&*~]/g;

                if (passwordField.val().length >= 8) {
                    $("#password-validation-check-length").css('display', 'block');
                    $("#password-validation-neutral-length").css('display', 'none');
                    $("#password-validation-cross-length").css('display', 'none');
                } else {
                    $("#password-validation-cross-length").css('display', 'block');
                    $("#password-validation-check-length").css('display', 'none');
                    $("#password-validation-neutral-length").css('display', 'none');
                }

                if (passwordField.val().match(lowerCaseLetters) && passwordField.val().match(upperCaseLetters)) {
                    $("#password-validation-check-case").css('display', 'block');
                    $("#password-validation-neutral-case").css('display', 'none');
                    $("#password-validation-cross-case").css('display', 'none');
                } else {
                    $("#password-validation-cross-case").css('display', 'block');
                    $("#password-validation-check-case").css('display', 'none');
                    $("#password-validation-neutral-case").css('display', 'none');
                }

                if (passwordField.val().match(numbers)) {
                    $("#password-validation-check-number").css('display', 'block');
                    $("#password-validation-neutral-number").css('display', 'none');
                    $("#password-validation-cross-number").css('display', 'none');
                } else {
                    $("#password-validation-cross-number").css('display', 'block');
                    $("#password-validation-check-number").css('display', 'none');
                    $("#password-validation-neutral-number").css('display', 'none');
                }

                if (passwordField.val().match(chars)) {
                    $("#password-validation-check-chars").css('display', 'block');
                    $("#password-validation-neutral-chars").css('display', 'none');
                    $("#password-validation-cross-chars").css('display', 'none');
                } else {
                    $("#password-validation-cross-chars").css('display', 'block');
                    $("#password-validation-check-chars").css('display', 'none');
                    $("#password-validation-neutral-chars").css('display', 'none');
                }
            }

            function displayConfirmPasswordCross() {
                if (passwordField.val() !== "" && passwordField.val() === passwordConfirmField.val()) {
                    $("#password-validation-check-match").css('display', 'block');
                    $("#password-validation-neutral-match").css('display', 'none');
                    $("#password-validation-cross-match").css('display', 'none');
                } else {
                    $("#password-validation-cross-match").css('display', 'block');
                    $("#password-validation-check-match").css('display', 'none');
                    $("#password-validation-neutral-match").css('display', 'none');
                }
            }
        </script>
    </body>
</html>
